@@ -49,7 +49,7 @@ setConstructorS3("MbeiPlm", function(...) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   args <- list(...);
   if (length(args) > 0 && !is.null(args[[1]])) {
-    require("affy") || throw("Package 'affy' not loaded.");
+    require("affy") || throw("Package not loaded: affy");
   }
 
   this <- extend(ProbeLevelModel(...), "MbeiPlm");
@@ -182,12 +182,19 @@ setMethodS3("getProbeAffinityFile", "MbeiPlm", function(this, ...) {
 # }
 #*/###########################################################################
 setMethodS3("getFitUnitGroupFunction", "MbeiPlm", function(this, ...) {
+  # To help 'R CMD check' to locate fit.li.wong().
+  require("affy") || throw("Package not loaded: affy");
+
   standardize <- this$standardize;
   shift <- this$shift;
   if (is.null(shift))
     shift <- 0;
 
-  liWong <- function(y, ...) {
+  liWong <- function(y, priors=NULL, ...) {
+    if (!is.null(priors)) {
+      throw("NOT IMPLEMENTED: Internal liWong() does not support prior parameters.");
+    }
+
     # Add shift
     y <- y + shift;
 
@@ -236,6 +243,13 @@ setMethodS3("getFitUnitGroupFunction", "MbeiPlm", function(this, ...) {
 
 ############################################################################
 # HISTORY:
+# 2012-03-23
+# o Now getFitUnitGroupFunction() for MbeiPlm helps 'R CMD check' to
+#   locate fit.li.wong() by explicitly requiring 'affy'.
+# 2012-01-14
+# o ROBUSTNESS: Now the fit functions of RmaPlm and MbeiPlm give an
+#   error whenever trying to use prior parameters, which are yet
+#   not supported.
 # 2006-12-18
 # o Now the fit function of the MBEI model treats single-probe unit groups
 #   specially; the affy::fit.li.wong() handled it already before, but 
