@@ -558,7 +558,7 @@ setMethodS3("process", "QuantileNormalization", function(this, ..., force=FALSE,
   # Garbage collect
   rm(params); gc();
 
-  verbose && cat(verbose, "Calling aroma.light::normalizeQuantile() with arguments:");
+  verbose && cat(verbose, "Calling normalizeQuantile() with arguments:");
   verbose && str(verbose, args);
   args$verbose <- verbose;
   outputDataSet <- do.call("normalizeQuantile", args=args);
