@@ -5,7 +5,7 @@ verbose <- Arguments$getVerbose(-3, timestamp=TRUE);
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Setup data set
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-name <- "Affymetrix-HeartBrain";
+dataSet <- "Affymetrix-HeartBrain";
 chipType <- "HuEx-1_0-st-v2";
 
 cdf <- AffymetrixCdfFile$byChipType(chipType, tags="coreR3,A20071112,EP");
@@ -13,7 +13,7 @@ cdf <- AffymetrixCdfFile$byChipType(chipType, tags="fullR3,A20071112,EP");
 print(cdf);
 
 # Setup CEL set using the core CDF.
-csR <- AffymetrixCelSet$byName(name=name, cdf=cdf);
+csR <- AffymetrixCelSet$byName(dataSet, cdf=cdf);
 print(csR);
 
 
